unofficial mirror of guix-devel@gnu.org 
 help / color / mirror / code / Atom feed
* [PATCH 1/4] gnu: talloc: Update to 2.1.5.
@ 2015-12-15  4:21 宋文武
  2015-12-15  4:22 ` [PATCH 2/4] gnu: Add tevent 宋文武
                   ` (3 more replies)
  0 siblings, 4 replies; 10+ messages in thread
From: 宋文武 @ 2015-12-15  4:21 UTC (permalink / raw)
  To: guix-devel; +Cc: 宋文武

* gnu/packages/samba.scm (talloc): Update to 2.1.5.
[arguments]: Use 'modify-phases' syntax.
---
 gnu/packages/samba.scm | 27 +++++++++++++++------------
 1 file changed, 15 insertions(+), 12 deletions(-)

diff --git a/gnu/packages/samba.scm b/gnu/packages/samba.scm
index 484eafb..e5f81a4 100644
--- a/gnu/packages/samba.scm
+++ b/gnu/packages/samba.scm
@@ -169,26 +169,29 @@ Desktops into Active Directory environments using the winbind daemon.")
 (define-public talloc
   (package
     (name "talloc")
-    (version "2.1.2")
+    (version "2.1.5")
     (source (origin
               (method url-fetch)
               (uri (string-append "https://www.samba.org/ftp/talloc/talloc-"
                                   version ".tar.gz"))
               (sha256
                (base32
-                "13c365f7y8idjf2v1jxdjpkc3lxdmsxxfxjx1ymianm7zjiph393"))))
+                "1pfx3kmj973hpacfw46fzfnjd7ms1j03ifkc30wk930brx8ffcrq"))))
     (build-system gnu-build-system)
     (arguments
-     '(#:phases (alist-replace
-                 'configure
-                 (lambda* (#:key outputs #:allow-other-keys)
-                   ;; talloc uses a custom configuration script that runs a
-                   ;; python script called 'waf'.
-                   (setenv "CONFIG_SHELL" (which "sh"))
-                   (let ((out (assoc-ref outputs "out")))
-                     (zero? (system* "./configure"
-                                     (string-append "--prefix=" out)))))
-                 %standard-phases)))
+     '(#:phases
+       (modify-phases %standard-phases
+         (replace 'configure
+           (lambda* (#:key outputs #:allow-other-keys)
+             ;; test_magic_differs.sh is a broken script, skip the test.
+             (substitute* "wscript"
+               (("magic_ret = .*") "magic_ret = 0\n"))
+             ;; talloc uses a custom configuration script that runs a
+             ;; python script called 'waf'.
+             (setenv "CONFIG_SHELL" (which "sh"))
+             (let ((out (assoc-ref outputs "out")))
+               (zero? (system* "./configure"
+                               (string-append "--prefix=" out)))))))))
     (inputs
      `(("python" ,python-2)))
     (home-page "http://talloc.samba.org")
-- 
2.5.0

^ permalink raw reply related	[flat|nested] 10+ messages in thread

end of thread, other threads:[~2015-12-21 13:40 UTC | newest]

Thread overview: 10+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2015-12-15  4:21 [PATCH 1/4] gnu: talloc: Update to 2.1.5 宋文武
2015-12-15  4:22 ` [PATCH 2/4] gnu: Add tevent 宋文武
2015-12-17 22:48   ` Ludovic Courtès
2015-12-15  4:22 ` [PATCH 3/4] gnu: Add ldb 宋文武
2015-12-17 22:49   ` Ludovic Courtès
2015-12-15  4:22 ` [PATCH 4/4] gnu: samba: Update to 4.3.2 宋文武
2015-12-17 22:51   ` Ludovic Courtès
2015-12-18  2:31     ` 宋文武
2015-12-21 13:39       ` Ludovic Courtès
2015-12-17 22:47 ` [PATCH 1/4] gnu: talloc: Update to 2.1.5 Ludovic Courtès

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/guix.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).